==> tapir-apispec-docs_3-1.10.8-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"tapir-apispec-docs","t":"tapir-apispec-docs","d":"","k":"static","x":""},
{"l":"sttp/tapir/docs/apispec.html#","e":false,"i":"","n":"sttp.tapir.docs.apispec","t":"sttp.tapir.docs.apispec","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/apispec/schema.html#","e":false,"i":"","n":"sttp.tapir.docs.apispec.schema","t":"sttp.tapir.docs.apispec.schema","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchema.html#","e":false,"i":"","n":"MetaSchema","t":"MetaSchema","d":"sttp.tapir.docs.apispec.schema","k":"trait","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchema.html#schemaId-0","e":false,"i":"","n":"schemaId","t":"schemaId: String","d":"sttp.tapir.docs.apispec.schema.MetaSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft04$.html#","e":false,"i":"","n":"MetaSchemaDraft04","t":"MetaSchemaDraft04 extends MetaSchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft04$.html#schemaId-0","e":false,"i":"","n":"schemaId","t":"schemaId: String","d":"sttp.tapir.docs.apispec.schema.MetaSchemaDraft04","k":"val","x":""},
{"l":"sttp/tapir/docs/apispec/schema/SchemasForEndpoints.html#","e":false,"i":"","n":"SchemasForEndpoints","t":"SchemasForEndpoints(es: Iterable[AnyEndpoint], schemaName: SName => String, markOptionsAsNullable: Boolean, additionalOutputs: List[EndpointOutput[_]])","d":"sttp.tapir.docs.apispec.schema","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/schema/SchemasForEndpoints.html#apply-ffffff32","e":false,"i":"","n":"apply","t":"apply(): (ListMap[SchemaId, Schema], TSchemaToASchema)","d":"sttp.tapir.docs.apispec.schema.SchemasForEndpoints","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#","e":false,"i":"","n":"TSchemaToASchema","t":"TSchemaToASchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#tDefaultToADefault-fffff3d1","e":false,"i":"","n":"tDefaultToADefault","t":"tDefaultToADefault(schema: Schema[_]): Option[ExampleValue]","d":"sttp.tapir.docs.apispec.schema.TSchemaToASchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#tExampleToAExample-fffff3d1","e":false,"i":"","n":"tExampleToAExample","t":"tExampleToAExample(schema: Schema[_]): Option[ExampleValue]","d":"sttp.tapir.docs.apispec.schema.TSchemaToASchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TapirSchemaToJsonSchema$.html#","e":false,"i":"","n":"TapirSchemaToJsonSchema","t":"TapirSchemaToJsonSchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TapirSchemaToJsonSchema$.html#apply-888","e":false,"i":"","n":"apply","t":"apply(schema: Schema[_], markOptionsAsNullable: Boolean, metaSchema: MetaSchema, schemaName: SName => String): Schema","d":"sttp.tapir.docs.apispec.schema.TapirSchemaToJsonSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension.html#","e":false,"i":"","n":"DocsExtension","t":"DocsExtension[A](key: String, value: A, codec: JsonCodec[A])","d":"sttp.tapir.docs.apispec","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension.html#rawValue-0","e":false,"i":"","n":"rawValue","t":"rawValue: String","d":"sttp.tapir.docs.apispec.DocsExtension","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension$.html#","e":false,"i":"","n":"DocsExtension","t":"DocsExtension","d":"sttp.tapir.docs.apispec","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension$.html#of-fffff53f","e":false,"i":"","n":"of","t":"of[A](key: String, value: A)(implicit codec: JsonCodec[A]): DocsExtension[A]","d":"sttp.tapir.docs.apispec.DocsExtension","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#","e":false,"i":"","n":"DocsExtensionAttribute","t":"DocsExtensionAttribute","d":"sttp.tapir.docs.apispec","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichBasicEndpointTransput-fffffdda","e":false,"i":"","n":"RichBasicEndpointTransput","t":"RichBasicEndpointTransput[E <: Atom[_]](e: E): RichBasicEndpointTransput[E]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointAuth-fffff1da","e":false,"i":"","n":"RichEndpointAuth","t":"RichEndpointAuth[T, TYPE <: AuthType](e: Auth[T, TYPE]): RichEndpointAuth[T, TYPE]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointIOInfo-fffff555","e":false,"i":"","n":"RichEndpointIOInfo","t":"RichEndpointIOInfo[T](i: Info[T]): RichEndpointIOInfo[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointInfo-fffff210","e":false,"i":"","n":"RichEndpointInfo","t":"RichEndpointInfo(i: EndpointInfo): RichEndpointInfo","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointInfoOps-fffffa8b","e":false,"i":"","n":"RichEndpointInfoOps","t":"RichEndpointInfoOps[E <: EndpointInfoOps[_]](e: E): RichEndpointInfoOps[E]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichSchema-33b","e":false,"i":"","n":"RichSchema","t":"RichSchema[T](s: Schema[T]): RichSchema[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichWebSocketBodyOutput-da7","e":false,"i":"","n":"RichWebSocketBodyOutput","t":"RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S](b: WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]): RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#docsExtensionAttributeKey-0","e":false,"i":"","n":"docsExtensionAttributeKey","t":"docsExtensionAttributeKey: AttributeKey[Vector[DocsExtension[_]]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"val","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#","e":false,"i":"","n":"RichBasicEndpointTransput","t":"RichBasicEndpointTransput[E <: Atom[_]](e: E)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#docsExtension-19e","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): E","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichBasicEndpointTransput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichBasicEndpointTransput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#","e":false,"i":"","n":"RichEndpointAuth","t":"RichEndpointAuth[T, TYPE <: AuthType](e: Auth[T, TYPE])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#docsExtension-ca0","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Auth[T, TYPE]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointAuth","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointAuth","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#","e":false,"i":"","n":"RichEndpointIOInfo","t":"RichEndpointIOInfo[T](i: Info[T])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#docsExtension-45a","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Info[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointIOInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointIOInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#","e":false,"i":"","n":"RichEndpointInfo","t":"RichEndpointInfo(i: EndpointInfo)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#docsExtension-e2a","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): EndpointInfo","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#","e":false,"i":"","n":"RichEndpointInfoOps","t":"RichEndpointInfoOps[E <: EndpointInfoOps[_]](e: E)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#docsExtension-28","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): E","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfoOps","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfoOps","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#","e":false,"i":"","n":"RichSchema","t":"RichSchema[T](s: Schema[T])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#docsExtension-128","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Schema[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#","e":false,"i":"","n":"RichWebSocketBodyOutput","t":"RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S](b: WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#requestsDocsExtension-fffff463","e":false,"i":"","n":"requestsDocsExtension","t":"requestsDocsExtension[A : JsonCodec](key: String, value: A): WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichWebSocketBodyOutput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#responsesDocsExtension-fffff463","e":false,"i":"","n":"responsesDocsExtension","t":"responsesDocsExtension[A : JsonCodec](key: String, value: A): WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichWebSocketBodyOutput","k":"def","x":""}];

==> tapir-apispec-docs_3-1.12.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"tapir-apispec-docs","t":"tapir-apispec-docs","d":"","k":"static","x":""},
{"l":"sttp/tapir/docs/apispec.html#","e":false,"i":"","n":"sttp.tapir.docs.apispec","t":"sttp.tapir.docs.apispec","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/apispec/schema.html#","e":false,"i":"","n":"sttp.tapir.docs.apispec.schema","t":"sttp.tapir.docs.apispec.schema","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchema.html#","e":false,"i":"","n":"MetaSchema","t":"MetaSchema","d":"sttp.tapir.docs.apispec.schema","k":"trait","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchema.html#schemaId-0","e":false,"i":"","n":"schemaId","t":"schemaId: String","d":"sttp.tapir.docs.apispec.schema.MetaSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft04$.html#","e":false,"i":"","n":"MetaSchemaDraft04","t":"MetaSchemaDraft04 extends MetaSchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft04$.html#schemaId-0","e":false,"i":"","n":"schemaId","t":"schemaId: String","d":"sttp.tapir.docs.apispec.schema.MetaSchemaDraft04","k":"val","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft202012$.html#","e":false,"i":"","n":"MetaSchemaDraft202012","t":"MetaSchemaDraft202012 extends MetaSchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/MetaSchemaDraft202012$.html#schemaId-0","e":false,"i":"","n":"schemaId","t":"schemaId: String","d":"sttp.tapir.docs.apispec.schema.MetaSchemaDraft202012","k":"val","x":""},
{"l":"sttp/tapir/docs/apispec/schema/SchemasForEndpoints.html#","e":false,"i":"","n":"SchemasForEndpoints","t":"SchemasForEndpoints(es: Iterable[AnyEndpoint], schemaName: SName => String, markOptionsAsNullable: Boolean, additionalOutputs: List[EndpointOutput[_]])","d":"sttp.tapir.docs.apispec.schema","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/schema/SchemasForEndpoints.html#apply-ffffff32","e":false,"i":"","n":"apply","t":"apply(): (ListMap[SchemaId, Schema], TSchemaToASchema)","d":"sttp.tapir.docs.apispec.schema.SchemasForEndpoints","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#","e":false,"i":"","n":"TSchemaToASchema","t":"TSchemaToASchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#tDefaultToADefault-fffff3d1","e":false,"i":"","n":"tDefaultToADefault","t":"tDefaultToADefault(schema: Schema[_]): Option[ExampleValue]","d":"sttp.tapir.docs.apispec.schema.TSchemaToASchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TSchemaToASchema$.html#tExampleToAExample-fffff3d1","e":false,"i":"","n":"tExampleToAExample","t":"tExampleToAExample(schema: Schema[_]): Option[ExampleValue]","d":"sttp.tapir.docs.apispec.schema.TSchemaToASchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TapirSchemaToJsonSchema$.html#","e":false,"i":"","n":"TapirSchemaToJsonSchema","t":"TapirSchemaToJsonSchema","d":"sttp.tapir.docs.apispec.schema","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/schema/TapirSchemaToJsonSchema$.html#apply-888","e":false,"i":"","n":"apply","t":"apply(schema: Schema[_], markOptionsAsNullable: Boolean, metaSchema: MetaSchema = ..., schemaName: SName => String = ...): Schema","d":"sttp.tapir.docs.apispec.schema.TapirSchemaToJsonSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension.html#","e":false,"i":"","n":"DocsExtension","t":"DocsExtension[A](key: String, value: A, codec: JsonCodec[A])","d":"sttp.tapir.docs.apispec","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension.html#rawValue-0","e":false,"i":"","n":"rawValue","t":"rawValue: String","d":"sttp.tapir.docs.apispec.DocsExtension","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension$.html#","e":false,"i":"","n":"DocsExtension","t":"DocsExtension","d":"sttp.tapir.docs.apispec","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtension$.html#of-fffff53f","e":false,"i":"","n":"of","t":"of[A](key: String, value: A)(implicit codec: JsonCodec[A]): DocsExtension[A]","d":"sttp.tapir.docs.apispec.DocsExtension","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#","e":false,"i":"","n":"DocsExtensionAttribute","t":"DocsExtensionAttribute","d":"sttp.tapir.docs.apispec","k":"object","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichBasicEndpointTransput-fffffdda","e":false,"i":"","n":"RichBasicEndpointTransput","t":"RichBasicEndpointTransput[E <: Atom[_]](e: E): RichBasicEndpointTransput[E]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointAuth-fffff1da","e":false,"i":"","n":"RichEndpointAuth","t":"RichEndpointAuth[T, TYPE <: AuthType](e: Auth[T, TYPE]): RichEndpointAuth[T, TYPE]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointIOInfo-fffff555","e":false,"i":"","n":"RichEndpointIOInfo","t":"RichEndpointIOInfo[T](i: Info[T]): RichEndpointIOInfo[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointInfo-fffff210","e":false,"i":"","n":"RichEndpointInfo","t":"RichEndpointInfo(i: EndpointInfo): RichEndpointInfo","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichEndpointInfoOps-fffffa8b","e":false,"i":"","n":"RichEndpointInfoOps","t":"RichEndpointInfoOps[E <: EndpointInfoOps[_]](e: E): RichEndpointInfoOps[E]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichSchema-33b","e":false,"i":"","n":"RichSchema","t":"RichSchema[T](s: Schema[T]): RichSchema[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#RichWebSocketBodyOutput-da7","e":false,"i":"","n":"RichWebSocketBodyOutput","t":"RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S](b: WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]): RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$.html#docsExtensionAttributeKey-0","e":false,"i":"","n":"docsExtensionAttributeKey","t":"docsExtensionAttributeKey: AttributeKey[Vector[DocsExtension[_]]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"val","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#","e":false,"i":"","n":"RichBasicEndpointTransput","t":"RichBasicEndpointTransput[E <: Atom[_]](e: E)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#docsExtension-19e","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): E","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichBasicEndpointTransput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichBasicEndpointTransput.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichBasicEndpointTransput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#","e":false,"i":"","n":"RichEndpointAuth","t":"RichEndpointAuth[T, TYPE <: AuthType](e: Auth[T, TYPE])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#docsExtension-ca0","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Auth[T, TYPE]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointAuth","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointAuth.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointAuth","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#","e":false,"i":"","n":"RichEndpointIOInfo","t":"RichEndpointIOInfo[T](i: Info[T])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#docsExtension-45a","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Info[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointIOInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointIOInfo.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointIOInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#","e":false,"i":"","n":"RichEndpointInfo","t":"RichEndpointInfo(i: EndpointInfo)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#docsExtension-e2a","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): EndpointInfo","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfo.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfo","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#","e":false,"i":"","n":"RichEndpointInfoOps","t":"RichEndpointInfoOps[E <: EndpointInfoOps[_]](e: E)","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#docsExtension-28","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): E","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfoOps","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichEndpointInfoOps.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichEndpointInfoOps","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#","e":false,"i":"","n":"RichSchema","t":"RichSchema[T](s: Schema[T])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#docsExtension-128","e":false,"i":"","n":"docsExtension","t":"docsExtension[D : JsonCodec](key: String, value: D): Schema[T]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichSchema.html#docsExtensions-0","e":false,"i":"","n":"docsExtensions","t":"docsExtensions: Vector[DocsExtension[_]]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichSchema","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#","e":false,"i":"","n":"RichWebSocketBodyOutput","t":"RichWebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S](b: WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S])","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute","k":"class","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#requestsDocsExtension-fffff463","e":false,"i":"","n":"requestsDocsExtension","t":"requestsDocsExtension[A : JsonCodec](key: String, value: A): WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichWebSocketBodyOutput","k":"def","x":""},
{"l":"sttp/tapir/docs/apispec/DocsExtensionAttribute$$RichWebSocketBodyOutput.html#responsesDocsExtension-fffff463","e":false,"i":"","n":"responsesDocsExtension","t":"responsesDocsExtension[A : JsonCodec](key: String, value: A): WebSocketBodyOutput[PIPE_REQ_RESP, REQ, RESP, T, S]","d":"sttp.tapir.docs.apispec.DocsExtensionAttribute.RichWebSocketBodyOutput","k":"def","x":""}];
